==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-spacer/translations/spacer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>Einstellungen des Abstandhalters</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>Abstandsbreite:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="40"/>
        <source>Space type:</source>
        <translation>Abstandstyp:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="57"/>
        <source>fixed</source>
        <translation>fest</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="71"/>
        <source>expandable</source>
        <translation>erweiterbar</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>liniert</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>punktiert</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>unsichtbar</translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.2.1.orig.tar.xz: lxqt-panel-1.2.1/plugin-spacer/translations/spacer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>Abstandhaltereinstellungen</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>Abstandsbreite:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="40"/>
        <source>Space type:</source>
        <translation>Abstandstyp:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="57"/>
        <source>fixed</source>
        <translation>fest</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="71"/>
        <source>expandable</source>
        <translation>erweiterbar</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>liniert</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>punktiert</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>unsichtbar</translation>
    </message>
</context>
</TS>
